@@ -1,5 +1,5 @@
 {-# LANGUAGE FlexibleInstances, ScopedTypeVariables, TypeSynonymInstances #-}
-{-# OPTIONS_GHC -fno-warn-orphans -fno-warn-name-shadowing #-}
+{-# OPTIONS_GHC -fno-warn-orphans -fno-warn-name-shadowing -fno-warn-unused-do-bind #-}
 module Debian.Control.String
     ( -- * Types
       Control'(..)
@@ -23,23 +23,23 @@ module Debian.Control.String
     , raiseFields
     ) where
 
-import qualified Control.Exception as E    
+import qualified Control.Exception as E
 import Data.Char (toLower)
 import Data.List
 import Text.ParserCombinators.Parsec
 import System.IO
 import Debian.Control.Common
+import Text.PrettyPrint.ANSI.Leijen (Pretty(pretty), text, vcat, empty)
 
--- |This may have bad performance issues 
-instance Show (Control' String) where
-    show (Control paragraph) = intercalate "\n" (map show paragraph)
+-- |This may have bad performance issues (why?)
+instance Pretty (Control' String) where
+    pretty (Control paragraphs) = vcat (map (\ p -> pretty p) paragraphs)
+instance Pretty (Paragraph' String) where
+    pretty (Paragraph fields) = vcat (map pretty fields ++ [empty])
 
-instance Show (Paragraph' String) where
-    show (Paragraph fields) = unlines (map show fields)
-
-instance Show (Field' String) where
-    show (Field (name,value)) = name ++":"++ value
-    show (Comment text) = text
+instance Pretty (Field' String) where
+    pretty (Field (name,value)) = text $ name ++":"++ value
+    pretty (Comment s) = text s
 
 type Field = Field' String
 type Control = Control' String
