@@ -4,11 +4,12 @@ module Debian.Relation
       PkgName(..)
     , SrcPkgName(..)
     , BinPkgName(..)
+    , Relations
     , AndRelation
     , OrRelation
-    , Relations
+    , prettyOrRelation
+    , prettyRelations
     , Relation(..)
-    , prettyRelation
     , ArchitectureReq(..)
     , VersionReq(..)
     -- * Helper Functions
@@ -18,5 +19,5 @@ module Debian.Relation
     , ParseRelations(..)
     ) where 
 
-import Debian.Relation.Common (prettyRelation, SrcPkgName(..), BinPkgName(..), PkgName(prettyPkgName, pkgNameFromString))
+import Debian.Relation.Common (SrcPkgName(..), BinPkgName(..), PkgName(pkgNameFromString), prettyOrRelation, prettyRelations)
 import Debian.Relation.String
